#[non_exhaustive]pub enum ColorChoice {
Auto,
Always,
Never,
}Expand description
When rendered failures should use ANSI color.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Color when the output looks like a terminal and NO_COLOR is unset.
This is the default.
Always
Always emit color, regardless of terminal detection or NO_COLOR.
Never
Never emit color.