pub trait ContainsAll<Item> {
// Required methods
fn first_unsatisfied(&self, items: &[&Item]) -> Option<Description>;
fn describe(&self) -> Description;
}Expand description
A tuple of matchers, all over the same Item, for contains_all.
Implemented for tuples of arity 2 through 8 by a macro in this module; you do not implement it yourself.
Required Methods
Sourcefn first_unsatisfied(&self, items: &[&Item]) -> Option<Description>
fn first_unsatisfied(&self, items: &[&Item]) -> Option<Description>
The description of the first matcher that no item in items satisfies,
or None if every matcher is satisfied.
Sourcefn describe(&self) -> Description
fn describe(&self) -> Description
The conjunction (a and b and ...) of the tuple’s descriptions.